@@ -25,7 +25,7 @@
 #' @importFrom tidyr gather everything
 #' @importFrom DT renderDT DTOutput datatable
 #' @importFrom h2o h2o.init as.h2o h2o.deeplearning h2o.varimp h2o.predict h2o.gbm h2o.naiveBayes h2o.randomForest h2o.automl h2o.clusterStatus
-#' @importFrom plotly plotlyOutput renderPlotly ggplotly plot_ly layout add_trace
+#' @importFrom plotly plotlyOutput renderPlotly ggplotly plot_ly layout add_trace hide_legend
 #' @importFrom shinyWidgets materialSwitch switchInput sendSweetAlert knobInput awesomeCheckbox actionBttn prettyCheckboxGroup
 #' @importFrom shinyjs useShinyjs hideElement
 #' @importFrom stats predict reorder cor acf
@@ -39,6 +39,9 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
   
   ## ---------------------------------------------------------------------------- INITIALISATION  -----------------------------------
   
+  # Ensure reproducibility
+  set.seed(123)
+  
   # Return an error if framework is not h2o or spark 
   if(!(framework %in% c("h2o","spark"))){stop("framework must be selected between h2o or spark")}
   
@@ -127,7 +130,8 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
   ACTUAL <- NULL
   Freq <- NULL 
   Error <- NULL 
-  predicted_label <- NULL 
+  predicted_label <- NULL
+  `..density..` <- NULL
   
   ## ---------------------------------------------------------------------------- UI  -----------------------------------
   
@@ -233,7 +237,7 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
                                                    ),
                                                    argonColumn(width = 6,
                                                                div(align = "center",
-                                                                   radioButtons(inputId = "input_var_graph_type",label = "",choices = c("Boxplot","Histogram","Autocorrelation"),selected = "Boxplot",inline = T)
+                                                                   radioButtons(inputId = "input_var_graph_type",label = "",choices = c("Histogram","Boxplot","Autocorrelation"),selected = "Histogram",inline = T)
                                                                ),
                                                                div(align = "center",uiOutput("message_autocorrelation")),
                                                                withSpinner(plotlyOutput("variable_boxplot", height = "100%", width = "100%")))
@@ -750,8 +754,8 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
     output$message_autocorrelation <- renderUI({
       
       points_serie <-eval(parse(text = paste0("data[,",colnames(data)[input$variables_class_input_rows_selected],"]"))) 
-      if (input$input_var_graph_type == "Autocorrelation" & !is.numeric(points_serie)){
-        argonH1("Only available for numerical variables",display = 4)
+      if (input$input_var_graph_type %in% c("Histogram","Autocorrelation") & !is.numeric(points_serie)){
+        argonH1(HTML("<br><br>Only available for numerical variables"),display = 4)
       }
     })
     
@@ -907,7 +911,15 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
       points_serie <-eval(parse(text = paste0("data[,",column_name,"]"))) 
       
       if (input$input_var_graph_type == "Histogram"){
-        plot_ly(x = points_serie,type = "histogram",name = column_name)
+        req(is.numeric(points_serie))
+        ggplotly(
+          ggplot(data = data,aes(x = eval(parse(text = column_name)),fill = column_name))+
+            xlab(column_name)+
+            geom_histogram(aes(y=..density..), colour="black", fill="#FCADB3",bins = 30)+
+            geom_density(alpha = 0.4,size = 1.3) +
+            scale_fill_manual(values="#56B4E9")+
+            theme_bw(),tooltip = "density"
+        ) %>% hide_legend()
       }
       else if (input$input_var_graph_type == "Boxplot"){
         plot_ly(x = points_serie,type = "box",name = column_name)
@@ -1281,6 +1293,11 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
         
       })
       
+      # Define data train when time series option is not selected
+      data_train_not_time_serie <- reactive({
+        data %>% sample_frac(as.numeric(as.character(gsub("%","",input$percentage_selector)))*0.01)
+      })
+      
       # Define a list of object related to model results (specific for H2O framework)
       table_forecast <- reactive({
         
@@ -1301,7 +1318,7 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
           
           req(!is.null(input$percentage_selector))
           
-          data_train <- data %>% sample_frac(as.numeric(as.character(gsub("%","",input$percentage_selector)))*0.01)
+          data_train <- data_train_not_time_serie()
           data_test <- data %>% anti_join(data_train ,by = colnames(data))
           data_results <- data_test
           
@@ -1344,7 +1361,7 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
                                   max_after_balance_size = parameter$max_after_balance_naiveBayes,
                                   min_sdev = parameter$min_sdev_naiveBayes,
                                   eps_sdev = parameter$epsilon_naiveBayes,
-                                  seed = 1
+                                  seed = 123
             )
             t2 <- Sys.time()
             time_naiveBayes <- data.frame(`Training time` =  paste0(round(t2 - t1,1)," seconds"), Model = "Naive Bayes")
@@ -1364,7 +1381,7 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
                                     sample_rate = parameter$subsampling_rate_random_forest,
                                     max_depth = parameter$max_depth_random_forest,
                                     nbins = parameter$n_bins_random_forest,
-                                    seed = 1
+                                    seed = 123
             )
             t2 <- Sys.time()
             time_random_forest <- data.frame(`Training time` =  paste0(round(t2 - t1,1)," seconds"), Model = "Random forest")
@@ -1386,7 +1403,7 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
                                     epochs = parameter$epochs_neural_net,
                                     rate = parameter$rate_neural_net,
                                     reproducible = T,
-                                    seed = 1
+                                    seed = 123
             )
             t2 <- Sys.time()
             
@@ -1409,7 +1426,7 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
                            max_depth = parameter$max_depth_gbm,
                            learn_rate = parameter$learn_rate_gbm,
                            min_rows = 2,
-                           seed = 1
+                           seed = 123
             )
             t2 <- Sys.time()
             time_gbm <- data.frame(`Training time` =  paste0(round(t2 - t1,1)," seconds"), Model = "Gradient boosted trees")
@@ -1431,7 +1448,7 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
                                      y = y,
                                      training_frame = data_h2o_train,
                                      max_runtime_secs = parameter$run_time_auto_ml,
-                                     seed = 1
+                                     seed = 123
                                      
             )
             
@@ -1572,6 +1589,11 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
         
       })
       
+      # Define data train when time series option is not selected
+      data_train_not_time_serie <- reactive({
+        data %>% sample_frac(as.numeric(as.character(gsub("%","",input$percentage_selector)))*0.01)
+      })
+      
       # Define a list of object related to model results (specific for Spark framework)
       table_forecast <- reactive({
         
@@ -1590,7 +1612,7 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
         else if (input$checkbox_time_series == FALSE){
           
           req(!is.null(input$percentage_selector))
-          data_train <- data %>% sample_frac(as.numeric(as.character(gsub("%","",input$percentage_selector)))*0.01)
+          data_train <- data_train_not_time_serie()
           data_test <- data %>% anti_join(data_train ,by = colnames(data))
           data_results <- data_test
           
@@ -1740,3 +1762,4 @@ shinyML_classification <- function(data = data,y,framework = "h2o", share_app =
   }
   else {runApp(app,quiet = TRUE,launch.browser = TRUE)}
 }
+
